==> huaweicloudsdkroma-3.0.83-py2.py3-none-any.whl: huaweicloudsdkroma/v2/model/product_templates_calculation.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ProductTemplatesCalculation:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'product_templates_numbers': 'int'
    }

    attribute_map = {
        'product_templates_numbers': 'product_templates_numbers'
    }

    def __init__(self, product_templates_numbers=None):
        """ProductTemplatesCalculation - a model defined in huaweicloud sdk"""
        
        

        self._product_templates_numbers = None
        self.discriminator = None

        if product_templates_numbers is not None:
            self.product_templates_numbers = product_templates_numbers

    @property
    def product_templates_numbers(self):
        """Gets the product_templates_numbers of this ProductTemplatesCalculation.

        产品模板数量

        :return: The product_templates_numbers of this ProductTemplatesCalculation.
        :rtype: int
        """
        return self._product_templates_numbers

    @product_templates_numbers.setter
    def product_templates_numbers(self, product_templates_numbers):
        """Sets the product_templates_numbers of this ProductTemplatesCalculation.

        产品模板数量

        :param product_templates_numbers: The product_templates_numbers of this ProductTemplatesCalculation.
        :type: int
        """
        self._product_templates_numbers = product_templates_numbers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductTemplatesCalculation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkroma-3.0.96-py2.py3-none-any.whl: huaweicloudsdkroma/v2/model/product_templates_calculation.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ProductTemplatesCalculation:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'product_templates_numbers': 'int'
    }

    attribute_map = {
        'product_templates_numbers': 'product_templates_numbers'
    }

    def __init__(self, product_templates_numbers=None):
        """ProductTemplatesCalculation

        The model defined in huaweicloud sdk

        :param product_templates_numbers: 产品模板数量
        :type product_templates_numbers: int
        """
        
        

        self._product_templates_numbers = None
        self.discriminator = None

        if product_templates_numbers is not None:
            self.product_templates_numbers = product_templates_numbers

    @property
    def product_templates_numbers(self):
        """Gets the product_templates_numbers of this ProductTemplatesCalculation.

        产品模板数量

        :return: The product_templates_numbers of this ProductTemplatesCalculation.
        :rtype: int
        """
        return self._product_templates_numbers

    @product_templates_numbers.setter
    def product_templates_numbers(self, product_templates_numbers):
        """Sets the product_templates_numbers of this ProductTemplatesCalculation.

        产品模板数量

        :param product_templates_numbers: The product_templates_numbers of this ProductTemplatesCalculation.
        :type product_templates_numbers: int
        """
        self._product_templates_numbers = product_templates_numbers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductTemplatesCalculation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
